@@ -1,11 +1,6 @@
-from cdh_dav_python.cdc_admin_service import (
-    environment_tracing as cdc_env_tracing,
-    environment_logging as cdc_env_logging
-)
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
 
-from cdh_dav_python.cdc_tech_environment_service import (
-    environment_http as cdc_env_http
-)
+from cdh_dav_python.cdc_tech_environment_service import environment_http as cdc_env_http
 
 
 import requests
@@ -64,7 +59,7 @@ class EdcAlationError(Exception):
         super().__init__(message)
 
 
-class CustomFields():
+class CustomFields:
     """
     A class for interacting with the bulk metadata upload from the Alation API.
     """
@@ -140,7 +135,7 @@ class CustomFields():
         indicates the presence of a special character, and the function returns
         True. Otherwise, it returns False.
         """
-        pattern = r'[^a-zA-Z0-9._]'
+        pattern = r"[^a-zA-Z0-9._]"
         # re.search returns a match object if the pattern is found in the string, and None otherwise
         match = re.search(pattern, string)
         return match is not None
@@ -153,16 +148,21 @@ class CustomFields():
             fields (Column, Table): An instance of either Column or Table class.
 
         Returns:
-            dict: A dictionary with 'title' and 'description' of the provided fields object. 
-            If 'title' or 'description' is None, it is not included in the dictionary. 
+            dict: A dictionary with 'title' and 'description' of the provided fields object.
+            If 'title' or 'description' is None, it is not included in the dictionary.
             If both are None, an empty dictionary is returned.
         """
         from .db_table import Table
+
         if isinstance(fields, (Column, Table)):
-            return {k: v for k, v in {
-                'title': fields.title,
-                'description': fields.description
-            }.items() if v is not None}
+            return {
+                k: v
+                for k, v in {
+                    "title": fields.title,
+                    "description": fields.description,
+                }.items()
+                if v is not None
+            }
         elif isinstance(fields, dict):
             return fields
         else:
@@ -184,7 +184,7 @@ class CustomFields():
         """
 
         # Split the key into components using the dot (.) separator
-        components = key.split('.')
+        components = key.split(".")
 
         # Extract ds_id, schema_name, table_name, and column
         ds_id = components[0]
@@ -195,18 +195,24 @@ class CustomFields():
         # Create a parameters dictionary for non-null values
         parameters = {}
         if ds_id:
-            parameters['ds_id'] = ds_id
+            parameters["ds_id"] = ds_id
         if schema_name:
-            parameters['schema_name'] = schema_name
+            parameters["schema_name"] = schema_name
         if table_name:
-            parameters['table_name'] = table_name
+            parameters["table_name"] = table_name
         if column:
-            parameters['name'] = column
-        parameters['limit'] = LIMIT
+            parameters["name"] = column
+        parameters["limit"] = LIMIT
 
         return parameters
 
-    def get_custom_fields(self, edc_alation_api_token, edc_alation_base_url):
+    def get_custom_fields(
+        self,
+        edc_alation_api_token,
+        edc_alation_base_url,
+        data_product_id: str,
+        environment: str,
+    ):
         """
         Retrieves data from a specified API endpoint.
 
@@ -221,62 +227,82 @@ class CustomFields():
             EdcAlationError: If there is an error during the retrieval process.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_custom_fields"):
             try:
                 params = {"limit": "1000"}
 
                 # Create headers
-                headers = {'Token': edc_alation_api_token,
-                           'Accept': 'application/json',
-                           'cache-control': "no-cache"
-                           }
+                headers = {
+                    "Token": edc_alation_api_token,
+                    "Accept": "application/json",
+                    "cache-control": "no-cache",
+                }
 
                 obj_http = cdc_env_http.EnvironmentHttp()
-                metadata_endpoint = '/integration/v2'
-                object_type = 'custom_field'
+                metadata_endpoint = "/integration/v2"
+                object_type = "custom_field"
                 api_url = f"{edc_alation_base_url}{metadata_endpoint}/{object_type}"
                 response_custom = obj_http.get(
-                    api_url, headers=headers, timeout=REQUEST_TIMEOUT, params=params)
+                    api_url,
+                    headers,
+                    REQUEST_TIMEOUT,
+                    params,
+                    data_product_id,
+                    environment,
+                )
 
-                response_custom.raise_for_status()
+                # Check the status code
+                if response_custom.status_code != 200:
+                    # Raise an exception if the status code is not 200 (OK)
+                    response_custom.raise_for_status()
 
                 custom_result = response_custom.json()
-                number_received = custom_result.get('number_received')
+                number_received = custom_result.get("number_received")
                 logger.info(f"number_received: {number_received}")
-                updated_objects = custom_result.get('updated_objects')
-                new_objects = custom_result.get('new_objects')
-                error_objects = custom_result.get('error_objects')
+                updated_objects = custom_result.get("updated_objects")
+                new_objects = custom_result.get("new_objects")
+                error_objects = custom_result.get("error_objects")
                 if error_objects and len(error_objects) > 0:
-                    error_message = ', '.join(str(e)
-                                              for e in error_objects)
+                    error_message = ", ".join(str(e) for e in error_objects)
                     raise EdcAlationError(
-                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}")
-                error = custom_result.get('error')
+                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}"
+                    )
+                error = custom_result.get("error")
                 if len(error) > 0:
                     raise EdcAlationError(
-                        f"Errors occurred: {error}: api_url {api_url}  : params {params}")
+                        f"Errors occurred: {error}: api_url {api_url}  : params {params}"
+                    )
 
                 if updated_objects == 0 and new_objects == 0:
                     error_message = "No objects updated or created"
                     raise EdcAlationError(
-                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}")
+                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}"
+                    )
 
                 return custom_result
 
             except Exception as ex:
                 error_msg = f"Error: {str(ex)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
-    def get_object_by_key(self, edc_alation_api_token, edc_alation_base_url, object_type, alation_datasource_id, key):
+    def get_object_by_key(
+        self,
+        edc_alation_api_token,
+        edc_alation_base_url,
+        object_type,
+        alation_datasource_id,
+        key,
+        data_product_id,
+        environment,
+    ):
         """
         Retrieves data from a specified API endpoint.
 
@@ -294,20 +320,15 @@ class CustomFields():
             EdcAlationError: If there is an error during the retrieval process.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_object_by_key"):
             try:
-
                 # Check if the alation_datasource_id is an integer
                 if not isinstance(alation_datasource_id, int):
-                    raise EdcAlationError(
-                        "alation_datasource_id must be an integer.")
+                    raise EdcAlationError("alation_datasource_id must be an integer.")
 
                 # Remove the data source ID from the key if it exists to avoid duplicate data source ID
                 key = key.replace(str(alation_datasource_id) + ".", "")
@@ -318,51 +339,66 @@ class CustomFields():
                 # Check if the key contains special characters
                 if self.has_special_chars(full_key):
                     logger.warning(
-                        f"The following submitted key contains special characters: {str(full_key)}")
+                        f"The following submitted key contains special characters: {str(full_key)}"
+                    )
 
                 # Create headers
-                headers = {'Token': edc_alation_api_token,
-                           'Content-Type': 'application/json',
-                           'Accept': 'application/json',
-                           'cache-control': "no-cache"
-                           }
+                headers = {
+                    "Token": edc_alation_api_token,
+                    "Content-Type": "application/json",
+                    "Accept": "application/json",
+                    "cache-control": "no-cache",
+                }
 
                 params = self.parse_key(full_key)
                 obj_http = cdc_env_http.EnvironmentHttp()
-                metadata_endpoint = '/integration/v2'
+                metadata_endpoint = "/integration/v2"
                 api_url = f"{edc_alation_base_url}{metadata_endpoint}/{object_type}"
                 response_custom = obj_http.get(
-                    api_url, headers=headers, timeout=REQUEST_TIMEOUT, params=params)
+                    api_url,
+                    headers,
+                    REQUEST_TIMEOUT,
+                    params,
+                    data_product_id,
+                    environment,
+                )
 
-                response_custom.raise_for_status()
+                # Check the status code
+                if response_custom.status_code != 200:
+                    # Raise an exception if the status code is not 200 (OK)
+                    response_custom.raise_for_status()
 
                 custom_result = response_custom.json()
-                number_received = custom_result.get('number_received')
+                number_received = custom_result.get("number_received")
                 logger.info(f"number_received: {number_received}")
-                updated_objects = custom_result.get('updated_objects')
-                new_objects = custom_result.get('new_objects')
-                error_objects = custom_result.get('error_objects')
+                updated_objects = custom_result.get("updated_objects")
+                new_objects = custom_result.get("new_objects")
+                error_objects = custom_result.get("error_objects")
                 if error_objects and len(error_objects) > 0:
-                    error_message = ', '.join(str(e)
-                                              for e in error_objects)
+                    error_message = ", ".join(str(e) for e in error_objects)
                     raise EdcAlationError(
-                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}")
-                error = custom_result.get('error')
+                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}"
+                    )
+                error = custom_result.get("error")
                 if len(error) > 0:
                     raise EdcAlationError(
-                        f"Errors occurred: {error}: api_url {api_url}  : params {params}")
+                        f"Errors occurred: {error}: api_url {api_url}  : params {params}"
+                    )
 
                 if updated_objects == 0 and new_objects == 0:
                     error_message = "No objects updated or created"
                     raise EdcAlationError(
-                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}")
+                        f"Errors occurred: {error_message}: api_url {api_url} : params {params}"
+                    )
 
                 return custom_result
 
             except Exception as ex:
                 error_msg = f"Error: {str(ex)} : {str(key)}: {str(object_type)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     def wrap_with_quotes(self, key):
@@ -386,44 +422,44 @@ class CustomFields():
             "example"
         """
 
-        if key.startswith("\"") and key.endswith("\""):
+        if key.startswith('"') and key.endswith('"'):
             return key  # Key is already wrapped
 
-        return f"\"{key}\""  # Wrap the key with double quotes
+        return f'"{key}"'  # Wrap the key with double quotes
 
     def encode_key_with_special_characters(self, key):
         special_characters = {
-            '!': '%21',
-            '"': '%22',
-            '#': '%23',
-            '$': '%24',
-            '%': '%25',
-            '&': '%26',
-            "'": '%27',
-            '(': '%28',
-            ')': '%29',
-            '*': '%2A',
-            '+': '%2B',
-            ',': '%2C',
-            '-': '%2D',
-            '.': '%2E',
-            '/': '%2F',
-            ':': '%3A',
-            ';': '%3B',
-            '<': '%3C',
-            '=': '%3D',
-            '>': '%3E',
-            '?': '%3F',
-            '@': '%40',
-            '[': '%5B',
-            '\\': '%5C',
-            ']': '%5D',
-            '^': '%5E',
-            '_': '%5F',
-            '`': '%60',
-            '{': '%7B',
-            '}': '%7D',
-            '~': '%7E'
+            "!": "%21",
+            '"': "%22",
+            "#": "%23",
+            "$": "%24",
+            "%": "%25",
+            "&": "%26",
+            "'": "%27",
+            "(": "%28",
+            ")": "%29",
+            "*": "%2A",
+            "+": "%2B",
+            ",": "%2C",
+            "-": "%2D",
+            ".": "%2E",
+            "/": "%2F",
+            ":": "%3A",
+            ";": "%3B",
+            "<": "%3C",
+            "=": "%3D",
+            ">": "%3E",
+            "?": "%3F",
+            "@": "%40",
+            "[": "%5B",
+            "\\": "%5C",
+            "]": "%5D",
+            "^": "%5E",
+            "_": "%5F",
+            "`": "%60",
+            "{": "%7B",
+            "}": "%7D",
+            "~": "%7E",
         }
 
         for char, escape_sequence in special_characters.items():
@@ -437,9 +473,15 @@ class CustomFields():
     # Recursive function to replace null with empty string
     def replace_null_with_empty(self, obj):
         if isinstance(obj, dict):
-            return {k: self.replace_null_with_empty(v) if v is not None else "N/A" for k, v in obj.items()}
+            return {
+                k: self.replace_null_with_empty(v) if v is not None else "N/A"
+                for k, v in obj.items()
+            }
         elif isinstance(obj, list):
-            return [self.replace_null_with_empty(elem) if elem is not None else "N/A" for elem in obj]
+            return [
+                self.replace_null_with_empty(elem) if elem is not None else "N/A"
+                for elem in obj
+            ]
         return obj
 
     def replace_nan_with_blank(self, d):
@@ -458,7 +500,20 @@ class CustomFields():
             return ""
         return d
 
-    def update(self, edc_alation_api_token, edc_alation_base_url, object_type, alation_datasource_id, key, fields_dict, force_submit, editable_fields, date_fields):
+    def update(
+        self,
+        edc_alation_api_token,
+        edc_alation_base_url,
+        object_type,
+        alation_datasource_id,
+        key,
+        fields_dict,
+        force_submit,
+        editable_fields,
+        date_fields,
+        data_product_id,
+        environment,
+    ):
         """
         Update business metadata on an object in Alation.
 
@@ -499,12 +554,9 @@ class CustomFields():
             If an error occurs during the update process.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME)
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("update"):
             array_of_json = None
@@ -516,6 +568,7 @@ class CustomFields():
                 # Check if the fields_dict is a Table object
                 # If it is a Table object, then extract the properties (attributes) to a dictionary with key-value pairs
                 from .db_table import Table
+
                 if isinstance(fields_dict, Table):
                     # Extract properties (attributes) to a dictionary with key-value pairs
                     fields_dict = vars(fields_dict)
@@ -536,10 +589,12 @@ class CustomFields():
                             fields = {key: fields_dict}
                         else:
                             logger.warning(
-                                f"Errors occurred and cannot process object {str(field_name)} of type: {type(fields_dict)} because it is not a valid Column in editable fields {str(editable_fields)}")
+                                f"Errors occurred and cannot process object {str(field_name)} of type: {type(fields_dict)} because it is not a valid Column in editable fields {str(editable_fields)}"
+                            )
                     else:
                         raise EdcAlationError(
-                            f"Errors occurred and cannot process object: {key} of type: {type(fields_dict)} because it is not a valid Table, Column or Dictionary: {str(fields_dict)}")
+                            f"Errors occurred and cannot process object: {key} of type: {type(fields_dict)} because it is not a valid Table, Column or Dictionary: {str(fields_dict)}"
+                        )
 
                 # If table check if the user is authorized to update the table
                 # if not isinstance(alation_datasource_id, int):
@@ -560,30 +615,32 @@ class CustomFields():
                 # Check if the key contains special characters
                 if self.has_special_chars(full_key):
                     logger.warning(
-                        f"The following submitted key contains special characters: {str(full_key)}")
+                        f"The following submitted key contains special characters: {str(full_key)}"
+                    )
 
                 # Create a new dictionary with only the valid editable fields
                 #  key.split(".")[-1] is field_name
-                fields_to_process = {key: value for key, value in fields.items()
-                                     if key.split(".")[-1] in editable_fields}
+                fields_to_process = {
+                    key: value
+                    for key, value in fields.items()
+                    if key.split(".")[-1] in editable_fields
+                }
 
                 # If the fields is a dictionary, then it is ready to queue for processing
                 if not isinstance(fields_to_process, dict):
                     error_msg = f"Errors occurred and cannot process object: {key} of type: {type(fields_dict)} because it is missing fields: {str(fields_dict)}"
                     raise EdcAlationError(error_msg)
 
-                params = {
-                    "create_new": "false",
-                    "replace_values": "true"
-                }
+                params = {"create_new": "false", "replace_values": "true"}
 
                 # Loop through the dictionary and urlencode the values
                 for key, value in fields_to_process.items():
                     # Encode keys if columns/attributes
                     if key == "key":
                         if object_type == "attribute":
-                            fields_to_process[key] = self.encode_key_with_special_characters(
-                                value)
+                            fields_to_process[
+                                key
+                            ] = self.encode_key_with_special_characters(value)
                     # Default to empty string if value is None
                     if value is None:
                         value = "N/A"
@@ -593,8 +650,7 @@ class CustomFields():
                 logger.info(f"single_update_init: {single_update_init}")
 
                 # Replace null values with empty strings
-                single_update = self.replace_null_with_empty(
-                    single_update_init)
+                single_update = self.replace_null_with_empty(single_update_init)
 
                 # Add the update to the updates list
                 # If there is a value to set in addition to key
@@ -606,8 +662,10 @@ class CustomFields():
                     data = ""
 
                     # Create json to validate
-                    array_of_json = [json.dumps(
-                        u, cls=EnhancedJSONEncoder, separators=(',', ':')) for u in self.updates]
+                    array_of_json = [
+                        json.dumps(u, cls=EnhancedJSONEncoder, separators=(",", ":"))
+                        for u in self.updates
+                    ]
                     if len(array_of_json) > 1:
                         data = ",".join(array_of_json)
                         data = "[" + data + "]"
@@ -618,8 +676,7 @@ class CustomFields():
                     try:
                         # Parse the data to check for JSON parsing errors
                         data_json = json.loads(data)
-                        logger.info(
-                            f"Successfully parsed data_json: {len(data_json)}")
+                        logger.info(f"Successfully parsed data_json: {len(data_json)}")
                     except json.JSONDecodeError as ex:
                         error_msg = f"Error parsing data_json: {ex} : {data}"
                         logger.error(error_msg)
@@ -627,59 +684,81 @@ class CustomFields():
 
                     cleaned_data = self.replace_nan_with_blank(self.updates)
 
-                    data_str = '\n'.join(json.dumps(item, cls=EnhancedJSONEncoder)
-                                         for item in cleaned_data)
+                    data_str = "\n".join(
+                        json.dumps(item, cls=EnhancedJSONEncoder)
+                        for item in cleaned_data
+                    )
 
                     # submit the batch
-                    logger.info(
-                        f"Submitting {object_type} batch")
-                    metadata_endpoint = '/api/v1/bulk_metadata/custom_fields/default'
+                    logger.info(f"Submitting {object_type} batch")
+                    metadata_endpoint = "/api/v1/bulk_metadata/custom_fields/default"
                     api_url = f"{edc_alation_base_url}{metadata_endpoint}/{object_type}"
 
                     # Create headers
-                    headers = {"Token": edc_alation_api_token,
-                               "Content-Type": "application/json",
-                               "accept": 'application/json'}
+                    headers = {
+                        "Token": edc_alation_api_token,
+                        "Content-Type": "application/json",
+                        "accept": "application/json",
+                    }
 
                     # Submit the updates using the constructed URL and data
                     response = requests.post(
-                        api_url, headers=headers, data=data_str, params=params, verify=True, timeout=REQUEST_TIMEOUT)
+                        api_url,
+                        headers=headers,
+                        data=data_str,
+                        params=params,
+                        verify=True,
+                        timeout=REQUEST_TIMEOUT,
+                    )
                     response_json = response.json()
 
                     # Clear updates after submission
                     self.updates = []
-                    logger.info(
-                        f"Response Status {object_type} batch of {data}")
+                    logger.info(f"Response Status {object_type} batch of {data}")
                     response.raise_for_status()
                     result = response_json
-                    number_received = result.get('number_received')
+                    number_received = result.get("number_received")
                     logger.info(f"number_received: {number_received}")
-                    updated_objects = result.get('updated_objects')
-                    new_objects = result.get('new_objects')
-                    error_objects = result.get('error_objects')
+                    updated_objects = result.get("updated_objects")
+                    new_objects = result.get("new_objects")
+                    error_objects = result.get("error_objects")
                     if error_objects and len(error_objects) > 0:
-                        error_message = ', '.join(str(e)
-                                                  for e in error_objects)
+                        error_message = ", ".join(str(e) for e in error_objects)
                         raise EdcAlationError(
-                            f"Errors occurred: {error_message}: api_url {api_url} : data {data}")
-                    error = result.get('error')
+                            f"Errors occurred: {error_message}: api_url {api_url} : data {data}"
+                        )
+                    error = result.get("error")
                     if len(error) > 0:
                         raise EdcAlationError(
-                            f"Errors occurred: {error}: api_url {api_url} : data {data}")
+                            f"Errors occurred: {error}: api_url {api_url} : data {data}"
+                        )
 
                     if updated_objects == 0 and new_objects == 0:
                         error_message = "No objects updated or created"
                         raise EdcAlationError(
-                            f"Errors occurred: {error_message}: api_url {api_url} : data {data}")
+                            f"Errors occurred: {error_message}: api_url {api_url} : data {data}"
+                        )
 
-                    return {"status": "success", "message": "Batch complete"}, response_json
+                    return {
+                        "status": "success",
+                        "message": "Batch complete",
+                    }, response_json
                 else:
-                    return {"status": "success", "message": "Batch not submitted"}, {"number_of_updates", len(self.updates), "batch_size", batch_size, "force_submit", force_submit}
+                    return {"status": "success", "message": "Batch not submitted"}, {
+                        "number_of_updates",
+                        len(self.updates),
+                        "batch_size",
+                        batch_size,
+                        "force_submit",
+                        force_submit,
+                    }
 
             except Exception as ex:
                 error_msg = f"Error: {str(ex)} : {str(key)}: {str(fields_dict)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
 
@@ -687,24 +766,16 @@ class EnhancedJSONEncoder(json.JSONEncoder):
     """
     JSON Encoder subclass that allows serialization of pandas Timestamp and NaT objects.
 
-    This encoder handles the problem where certain Python objects, like pandas Timestamps 
-    and NaT, are not directly serializable to JSON using the standard library's json module. 
-    Timestamp objects are converted to string representations, while NaT values are transformed 
+    This encoder handles the problem where certain Python objects, like pandas Timestamps
+    and NaT, are not directly serializable to JSON using the standard library's json module.
+    Timestamp objects are converted to string representations, while NaT values are transformed
     into None (or any other representation you prefer).
 
-    Example:
-        data = {
-            'time': pd.Timestamp('2022-05-05'),
-            'missing_time': pd.NaT,
-            'value': 42
-        }
-
-        json_str = json.dumps(data, cls=EnhancedJSONEncoder)
     """
 
     def default(self, obj):
         if isinstance(obj, pd.Timestamp):
-            return obj.strftime('%Y-%m-%d %H:%M:%S')
+            return obj.strftime("%Y-%m-%d %H:%M:%S")
         elif pd.isna(obj):  # This checks for both NaT and NaN
             return None  # or use a string like "null" or "missing"
         return super().default(obj)
