@@ -14,16 +14,15 @@ from .json_manifest import ManifestJson
 
 import pandas as pd
 
-from cdh_dav_python.cdc_admin_service import (
-    environment_tracing as cdc_env_tracing,
-    environment_logging as cdc_env_logging,
-)
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
 
 from cdh_dav_python.cdc_tech_environment_service import (
     environment_file as cdc_env_file,
     environment_http as cdc_env_http,
 )
 
+from cdh_dav_python.cdc_admin_service.environment_logging import LoggerSingleton
+
 
 # Get the currently running file name
 NAMESPACE_NAME = os.path.basename(os.path.dirname(__file__))
@@ -57,7 +56,11 @@ class Schema:
 
     @staticmethod
     def fetch_schema(
-        edc_alation_api_token, edc_alation_base_url, alation_schema_id
+        edc_alation_api_token,
+        edc_alation_base_url,
+        alation_schema_id,
+        data_product_id,
+        environment,
     ):
         """
         Retrieves details for a specific schema from Alation using the provided schema ID.
@@ -71,18 +74,11 @@ class Schema:
             dict: A dictionary containing details of the schema.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
-        with tracer.start_as_current_span(
-            "fetch_schema_" + str(alation_schema_id)
-        ):
+        with tracer.start_as_current_span("fetch_schema_" + str(alation_schema_id)):
             try:
                 # Log the parameters
                 logger.info(
@@ -90,9 +86,7 @@ class Schema:
                     str(len(edc_alation_api_token)),
                 )
                 logger.info("alation_schema_id: %s", str(alation_schema_id))
-                logger.info(
-                    "edc_alation_base_url: %s", str(edc_alation_base_url)
-                )
+                logger.info("edc_alation_base_url: %s", str(edc_alation_base_url))
                 schema_id = alation_schema_id
 
                 # Set the headers for the request
@@ -141,22 +135,14 @@ class Schema:
                         return response_schema, datasource_result
                     else:
                         response_schema_text = schema_result.get("reason")
-                        error_msg = "Failed to get schema:" + str(
-                            response_schema_text
-                        )
+                        error_msg = "Failed to get schema:" + str(response_schema_text)
                         error_msg = error_msg + " for api_url: " + str(api_url)
+                        error_msg = error_msg + " for schema_id: " + str(schema_id)
                         error_msg = (
-                            error_msg + " for schema_id: " + str(schema_id)
+                            error_msg + " and datasource_id: " + str(datasource_id)
                         )
                         error_msg = (
-                            error_msg
-                            + " and datasource_id: "
-                            + str(datasource_id)
-                        )
-                        error_msg = (
-                            error_msg
-                            + " and schema_result: "
-                            + str(schema_result)
+                            error_msg + " and schema_result: " + str(schema_result)
                         )
                         logger.error(error_msg)
                         raise EdcAlationError(error_msg)
@@ -166,12 +152,18 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
     def get_excel_manifest_file_path_temp(
-        upload_or_download, repository_path, environment, alation_user_id
+        upload_or_download,
+        repository_path,
+        environment,
+        alation_user_id,
+        data_product_id,
     ):
         """
         Constructs a temporary path for an Excel manifest file based on various parameters and the current date/time.
@@ -189,14 +181,9 @@ class Schema:
             Exception: If an error occurs during the construction of the Excel file path.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_excel_manifest_file_path_temp"):
             try:
@@ -245,9 +232,7 @@ class Schema:
                     + "s"
                     + "/"
                 )
-                manifest_path = obj_file.convert_to_current_os_dir(
-                    manifest_path
-                )
+                manifest_path = obj_file.convert_to_current_os_dir(manifest_path)
                 logger.info("manifest_path: " + manifest_path)
 
                 manifest_excel_file = manifest_path + file_name
@@ -258,7 +243,9 @@ class Schema:
                 # Corrected error message formatting
                 error_msg = f"Excel Error: {str(ex)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
@@ -269,6 +256,7 @@ class Schema:
         schema_name,
         environment,
         alation_user_id,
+        data_product_id,
     ):
         """_summary_
 
@@ -283,14 +271,9 @@ class Schema:
             environment (_type_): _description_
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_excel_manifest_file_path"):
             try:
@@ -342,9 +325,7 @@ class Schema:
                     + "s"
                     + "/"
                 )
-                manifest_path = obj_file.convert_to_current_os_dir(
-                    manifest_path
-                )
+                manifest_path = obj_file.convert_to_current_os_dir(manifest_path)
                 logger.info("manifest_path: " + manifest_path)
 
                 manifest_excel_file = manifest_path + file_name
@@ -355,7 +336,9 @@ class Schema:
                 # Corrected error message formatting
                 error_msg = f"Excel Error: {str(ex)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
@@ -366,6 +349,7 @@ class Schema:
         schema_name,
         environment,
         alation_user_id,
+        data_product_id,
     ):
         """Get the file name for the manifest JSON file.
 
@@ -381,14 +365,9 @@ class Schema:
             str: The file name for the manifest JSON file.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("get_json_manifest_file_path"):
             try:
@@ -443,9 +422,7 @@ class Schema:
                 right_most_150_chars = file_name[-80:]
                 file_name = right_most_150_chars
 
-                manifest_path = obj_file.convert_to_current_os_dir(
-                    manifest_path
-                )
+                manifest_path = obj_file.convert_to_current_os_dir(manifest_path)
                 manifest_file = manifest_path + file_name
 
                 logger.info(f"manifest_file: {manifest_file}")
@@ -454,11 +431,15 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
-    def get_json_data_definition_file_path(repository_path, environment):
+    def get_json_data_definition_file_path(
+        repository_path, environment, data_product_id
+    ):
         """
         Get the file path for the 'manifest.schema.json' file associated with the specified environment.
 
@@ -487,18 +468,11 @@ class Schema:
             # Output: '/path/to/repository/dev_data_definitions/manifest.schema.json'
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
-        with tracer.start_as_current_span(
-            "get_json_data_definition_file_path"
-        ):
+        with tracer.start_as_current_span("get_json_data_definition_file_path"):
             try:
                 obj_file = cdc_env_file.EnvironmentFile()
                 data_definition_path = (
@@ -525,7 +499,9 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
@@ -558,18 +534,11 @@ class Schema:
             # Output: '/path/to/repository/dev_data_definitions/excel_data_definition_for_tables_sql.xlsx'
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
-        with tracer.start_as_current_span(
-            "get_excel_data_definition_file_path"
-        ):
+        with tracer.start_as_current_span("get_excel_data_definition_file_path"):
             try:
                 obj_file = cdc_env_file.EnvironmentFile()
                 data_definition_path = (
@@ -581,9 +550,7 @@ class Schema:
                 )
 
                 logger.info("data_definition_path: " + data_definition_path)
-                data_definition_xls_file = (
-                    "excel_data_definition_for_tables_sql.xlsx"
-                )
+                data_definition_xls_file = "excel_data_definition_for_tables_sql.xlsx"
 
                 # Join the directory path with the filename
                 excel_data_definition_file_path = os.path.join(
@@ -598,12 +565,14 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @classmethod
     def download_manifest_excel(
-        cls, alation_schema_id, config, json_data_definition_file_path
+        cls, alation_schema_id, config, json_data_definition_file_path, data_product_id
     ):
         """
         Downloads the schema manifest Excel file for a given Alation schema ID.
@@ -630,14 +599,9 @@ class Schema:
             If an error occurs during the operation, an exception is raised and logged.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("download_manifest_excel"):
             try:
@@ -674,7 +638,9 @@ class Schema:
             except Exception as ex:
                 error_msg = "Excel Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @staticmethod
@@ -703,14 +669,12 @@ class Schema:
             represent properties of the schema and their corresponding values as present in the Alation system.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        data_product_id = config["data_product_id"]
+        environment = config["environment"]
+
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         schema_id = alation_schema_id
         schema_name = None
@@ -729,9 +693,7 @@ class Schema:
                 logger.info(f"schema_id: {schema_id}")
 
                 if not edc_alation_base_url:
-                    raise ValueError(
-                        "edc_alation_base_url is not set in config."
-                    )
+                    raise ValueError("edc_alation_base_url is not set in config.")
 
                 # Get the Alation API Access Token
                 token_endpoint = TokenEndpoint(edc_alation_base_url)
@@ -763,18 +725,12 @@ class Schema:
                 alation_datasource_id = datasource_id
 
                 # Log the schema details
-                logger.info(
-                    f"schema_result length: {str(len(schema_result_json))}"
-                )
-                logger.info(
-                    f"datasource_result length: {str(len(datasource_result))}"
-                )
+                logger.info(f"schema_result length: {str(len(schema_result_json))}")
+                logger.info(f"datasource_result length: {str(len(datasource_result))}")
 
-                json_data_definition_file_path = (
-                    cls.get_json_data_definition_file_path(
-                        repository_path=repository_path,
-                        environment=environment,
-                    )
+                json_data_definition_file_path = cls.get_json_data_definition_file_path(
+                    repository_path=repository_path,
+                    environment=environment,
                 )
                 # Get the schema manifest
                 msg = f"Loading manifest schema from {json_data_definition_file_path}"
@@ -834,7 +790,9 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @classmethod
@@ -864,9 +822,10 @@ class Schema:
         """
 
         try:
-            logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-                NAMESPACE_NAME, SERVICE_NAME
-            )
+            tracer, logger = LoggerSingleton.instance(
+                NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+            ).initialize_logging_and_tracing()
+
             logger = logger_singleton.get_logger()
             tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
                 NAMESPACE_NAME, SERVICE_NAME
@@ -886,12 +845,16 @@ class Schema:
                 except requests.exceptions.RequestException as ex_r:
                     error_msg = "Error in requests: %s", str(ex_r)
                     exc_info = sys.exc_info()
-                    logger_singleton.error_with_exception(error_msg, exc_info)
+                    LoggerSingleton.instance(
+                        NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                    ).error_with_exception(error_msg, exc_info)
                     raise
                 except Exception as ex_:
                     error_msg = "Error: %s", str(ex_)
                     exc_info = sys.exc_info()
-                    logger_singleton.error_with_exception(error_msg, exc_info)
+                    LoggerSingleton.instance(
+                        NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                    ).error_with_exception(error_msg, exc_info)
                     raise
 
                 logger.info(f"Info for schema ID: {alation_schema_id}")
@@ -923,8 +886,8 @@ class Schema:
                                 # Check if this field is in the list of custom fields
                                 found_custom_field = False
                                 for custom_field in schema["custom_fields"]:
-                                    formatted_field_name = (
-                                        field.lower().replace(" ", "")
+                                    formatted_field_name = field.lower().replace(
+                                        " ", ""
                                     )
                                     formatted_custom_field_name = (
                                         custom_field["field_name"]
@@ -936,29 +899,18 @@ class Schema:
                                         in formatted_custom_field_name
                                     ):
                                         found_custom_field = True
-                                        manifest_dict[field] = custom_field[
-                                            "value"
-                                        ]
+                                        manifest_dict[field] = custom_field["value"]
                                 # Exceptions to the rule - Fields that need to be manually mapped
                                 if not found_custom_field:
                                     # Enter the schema name in the identifier field
-                                    if (
-                                        field == "identifier"
-                                        and "name" in schema
-                                    ):
+                                    if field == "identifier" and "name" in schema:
                                         manifest_dict[field] = schema["name"]
                                     elif field == "alationDatasourceID":
-                                        manifest_dict[
-                                            field
-                                        ] = alation_datasource_id
+                                        manifest_dict[field] = alation_datasource_id
                                     elif field == "alationSchemaID":
-                                        manifest_dict[
-                                            field
-                                        ] = alation_schema_id
+                                        manifest_dict[field] = alation_schema_id
                                     else:
-                                        manifest_dict[field] = schema_fields[
-                                            field
-                                        ]
+                                        manifest_dict[field] = schema_fields[field]
 
                         # Get the json schema file path
                         # TODO Pass in the json schema file path
@@ -977,9 +929,7 @@ class Schema:
 
                         if tables_dict:
                             # Determine the number of threads to use
-                            num_threads = min(
-                                NUM_THREADS_MAX, len(tables_dict)
-                            )
+                            num_threads = min(NUM_THREADS_MAX, len(tables_dict))
 
                             # Using ThreadPoolExecutor
                             with concurrent.futures.ThreadPoolExecutor(
@@ -1006,9 +956,7 @@ class Schema:
                                 for future in concurrent.futures.as_completed(
                                     futures.values()
                                 ):
-                                    manifest_dict["tables"].append(
-                                        future.result()
-                                    )
+                                    manifest_dict["tables"].append(future.result())
                         else:
                             error_msg = "No tables found"
                             raise EdcAlationError(error_msg)
@@ -1027,9 +975,7 @@ class Schema:
             raise EdcAlationError(error_msg) from ex
 
     @classmethod
-    def upload_manifest_json(
-        cls, metadata_json_data, config, authenticated_user_id
-    ):
+    def upload_manifest_json(cls, metadata_json_data, config, authenticated_user_id):
         """
         Uploads a schema manifest to Alation.
 
@@ -1049,14 +995,12 @@ class Schema:
             manifest_dict (dict): A dictionary with the key "result" set to "success" if the operation completes successfully.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        data_product_id = config["data_product_id"]
+        environment = config["environment"]
+
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("upload_schema_manifest"):
             try:
@@ -1079,9 +1023,7 @@ class Schema:
                     edc_alation_api_token,
                     alation_refresh_token,
                 ) = token_endpoint.get_api_token_from_config(config)
-                logger.info(
-                    f"get_api_token_from_config:status_code:{status_code}"
-                )
+                logger.info(f"get_api_token_from_config:status_code:{status_code}")
                 msg = f"edc_alation_api_token length:{str(len(edc_alation_api_token))}"
                 logger.info(msg)
 
@@ -1103,10 +1045,8 @@ class Schema:
                 alation_datasource_id = datasource_results.get("id")
 
                 # Get the json schema file path
-                json_data_definition_file_path = (
-                    cls.get_json_data_definition_file_path(
-                        repository_path, environment
-                    )
+                json_data_definition_file_path = cls.get_json_data_definition_file_path(
+                    repository_path, environment
                 )
                 from .db_table import Table
 
@@ -1125,10 +1065,8 @@ class Schema:
 
                 schema = manifest.fetch_schema_data()
 
-                excel_data_definition_file = (
-                    cls.get_excel_data_definition_file_path(
-                        repository_path, environment
-                    )
+                excel_data_definition_file = cls.get_excel_data_definition_file_path(
+                    repository_path, environment
                 )
                 df_table_fields_data_definition = pd.read_excel(
                     excel_data_definition_file
@@ -1182,12 +1120,8 @@ class Schema:
                         "Created custom fields endpoint for updating custom fields via API"
                     )
 
-                    tags_endpoint = Tags(
-                        edc_alation_api_token, edc_alation_base_url
-                    )
-                    logger.info(
-                        "Created tags endpoint for updating tags via API"
-                    )
+                    tags_endpoint = Tags(edc_alation_api_token, edc_alation_base_url)
+                    logger.info("Created tags endpoint for updating tags via API")
 
                     id_finder_endpoint = IdFinder(
                         edc_alation_api_token, edc_alation_base_url
@@ -1222,9 +1156,7 @@ class Schema:
                         date_fields=date_fields,
                     )
                     logger.info("response_content: " + str(response_content))
-                    schema_key = (
-                        str(alation_datasource_id) + "." + encoded_schema_name
-                    )
+                    schema_key = str(alation_datasource_id) + "." + encoded_schema_name
                     schema_id = id_finder_endpoint.find("schema", schema_key)
                     for tag in manifest.tags:
                         tags_endpoint.apply("schema", schema_id, tag)
@@ -1273,9 +1205,7 @@ class Schema:
                                     table_name=table_name,
                                     date_fields=date_fields,
                                 )
-                                logger.info(
-                                    "table_result: " + str(table_result)
-                                )
+                                logger.info("table_result: " + str(table_result))
                             # Commented out the threading because complexity not worth it
                             # compared to batching updates in sets of 50
                             # and limiting updates to differences
@@ -1317,7 +1247,9 @@ class Schema:
             except Exception as ex:
                 error_msg = "Error: %s", ex
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
 
     @classmethod
@@ -1347,14 +1279,12 @@ class Schema:
             manifest_dict (dict): A dictionary with the key "result" set to "success" if the operation completes successfully.
         """
 
-        logger_singleton = cdc_env_logging.LoggerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        logger = logger_singleton.get_logger()
-        tracer_singleton = cdc_env_tracing.TracerSingleton.instance(
-            NAMESPACE_NAME, SERVICE_NAME
-        )
-        tracer = tracer_singleton.get_tracer()
+        data_product_id = config["data_product_id"]
+        environment = config["environment"]
+
+        tracer, logger = LoggerSingleton.instance(
+            NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+        ).initialize_logging_and_tracing()
 
         with tracer.start_as_current_span("upload_schema_manifest"):
             try:
@@ -1364,10 +1294,8 @@ class Schema:
                 repository_path = config.get("repository_path")
                 environment = config.get("environment")
                 alation_user_id = config.get("edc_alation_user_id")
-                json_data_definition_file_path = (
-                    cls.get_json_data_definition_file_path(
-                        repository_path, environment
-                    )
+                json_data_definition_file_path = cls.get_json_data_definition_file_path(
+                    repository_path, environment
                 )
                 logger.info(f"alation_user_id:{alation_user_id}")
 
@@ -1378,9 +1306,7 @@ class Schema:
                     edc_alation_api_token,
                     alation_refresh_token,
                 ) = token_endpoint.get_api_token_from_config(config)
-                logger.info(
-                    f"get_api_token_from_config:status_code:{status_code}"
-                )
+                logger.info(f"get_api_token_from_config:status_code:{status_code}")
                 msg = f"edc_alation_api_token length:{str(len(edc_alation_api_token))}"
                 logger.info(msg)
 
@@ -1390,10 +1316,8 @@ class Schema:
                 from .excel_manifest import ManifestExcel
 
                 manifest_excel = ManifestExcel()
-                df_tables = (
-                    manifest_excel.read_manifest_excel_file_tables_worksheet(
-                        manifest_excel_file_path
-                    )
+                df_tables = manifest_excel.read_manifest_excel_file_tables_worksheet(
+                    manifest_excel_file_path
                 )
                 alation_schema_id = df_tables["schema_id"][0]
                 logger.info(f"alation_schema_id:{alation_schema_id}")
@@ -1421,10 +1345,8 @@ class Schema:
                     schema_results,
                 )
 
-                excel_data_definition_file = (
-                    cls.get_excel_data_definition_file_path(
-                        repository_path, environment
-                    )
+                excel_data_definition_file = cls.get_excel_data_definition_file_path(
+                    repository_path, environment
                 )
                 df_table_fields_data_definition = pd.read_excel(
                     excel_data_definition_file
@@ -1449,12 +1371,8 @@ class Schema:
                         "Created custom fields endpoint for updating custom fields via API"
                     )
 
-                    tags_endpoint = Tags(
-                        edc_alation_api_token, edc_alation_base_url
-                    )
-                    logger.info(
-                        "Created tags endpoint for updating tags via API"
-                    )
+                    tags_endpoint = Tags(edc_alation_api_token, edc_alation_base_url)
+                    logger.info("Created tags endpoint for updating tags via API")
 
                     id_finder_endpoint = IdFinder(
                         edc_alation_api_token, edc_alation_base_url
@@ -1487,9 +1405,7 @@ class Schema:
                     #    tags_endpoint.apply('schema', schema_id, tag)
 
                     # Convert df_tables to a dictionary with 'table_name' as the key
-                    tables_dict = df_tables.set_index("name").to_dict(
-                        orient="index"
-                    )
+                    tables_dict = df_tables.set_index("name").to_dict(orient="index")
 
                     logger.info("tables_dict: " + str(tables_dict))
                     authorized_tables = {}
@@ -1572,5 +1488,7 @@ class Schema:
             except Exception as ex:
                 error_msg = f"Error: {str(ex)}"
                 exc_info = sys.exc_info()
-                logger_singleton.error_with_exception(error_msg, exc_info)
+                LoggerSingleton.instance(
+                    NAMESPACE_NAME, SERVICE_NAME, data_product_id, environment
+                ).error_with_exception(error_msg, exc_info)
                 raise
